@@ -2,8 +2,9 @@
 
 import importlib
 import pathlib
+import platform
 from datetime import datetime
-from typing import List, Tuple
+from typing import List, Optional, Tuple
 
 import click
 
@@ -15,18 +16,28 @@ PLUGIN_MODULE = "tartufo.commands"
 
 
 class TartufoCLI(click.MultiCommand):
-    def list_commands(self, ctx: click.Context) -> List[str]:
-        return [
-            fpath.name[:-3].replace("_", "-")
-            for fpath in PLUGIN_DIR.glob("*.py")
-            if fpath.name != "__init__.py"
-        ]
+    _valid_commands: Optional[List[str]] = None
 
-    def get_command(self, ctx: click.Context, cmd_name: str) -> click.Command:
-        module = importlib.import_module(
-            f".{cmd_name.replace('-', '_')}", PLUGIN_MODULE
-        )
-        return module.main  # type: ignore
+    @property
+    def custom_commands(self):
+        if self._valid_commands is None:
+            self._valid_commands = [
+                fpath.name[:-3].replace("_", "-")
+                for fpath in PLUGIN_DIR.glob("*.py")
+                if fpath.name != "__init__.py"
+            ]
+        return self._valid_commands
+
+    def list_commands(self, ctx: click.Context) -> List[str]:
+        return self.custom_commands
+
+    def get_command(self, ctx: click.Context, cmd_name: str) -> Optional[click.Command]:
+        if cmd_name in self.custom_commands:
+            module = importlib.import_module(
+                f".{cmd_name.replace('-', '_')}", PLUGIN_MODULE
+            )
+            return module.main  # type: ignore
+        return None
 
 
 @click.command(
@@ -135,6 +146,7 @@ class TartufoCLI(click.MultiCommand):
     callback=config.read_pyproject_toml,
     help="Read configuration from specified file. [default: tartufo.toml]",
 )
+
 # The first positional argument here would be a hard-coded version, hence the `None`
 @click.version_option(None, "-V", "--version")
 @click.pass_context
@@ -162,6 +174,9 @@ def process_issues(
     output_dir = None
     if options.output_dir:
         now = datetime.now().isoformat("T", "microseconds")
+        if platform.system().lower() == "windows":  # pragma: no cover
+            # Make sure we aren't using illegal characters for Windows folder names
+            now = now.replace(":", "")
         output_dir = pathlib.Path(options.output_dir) / f"tartufo-scan-results-{now}"
         output_dir.mkdir(parents=True)
 
